==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/inputs/StorageLensConfigurationStorageLensConfigurationExcludeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.inputs

import com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property buckets List of S3 bucket ARNs.
 * @property regions List of AWS Regions.
 */
public data class StorageLensConfigurationStorageLensConfigurationExcludeArgs(
    public val buckets: Output<List<String>>? = null,
    public val regions: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs> {
    override fun toJava():
        com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs =
        com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs.builder()
            .buckets(buckets?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [StorageLensConfigurationStorageLensConfigurationExcludeArgs].
 */
@PulumiTagMarker
public class StorageLensConfigurationStorageLensConfigurationExcludeArgsBuilder internal
constructor() {
    private var buckets: Output<List<String>>? = null

    private var regions: Output<List<String>>? = null

    /**
     * @param value List of S3 bucket ARNs.
     */
    @JvmName("dvykqjkgeubfmluq")
    public suspend fun buckets(`value`: Output<List<String>>) {
        this.buckets = value
    }

    @JvmName("umflxdkqfxscmbhd")
    public suspend fun buckets(vararg values: Output<String>) {
        this.buckets = Output.all(values.asList())
    }

    /**
     * @param values List of S3 bucket ARNs.
     */
    @JvmName("qsbvuchphyfxpyrb")
    public suspend fun buckets(values: List<Output<String>>) {
        this.buckets = Output.all(values)
    }

    /**
     * @param value List of AWS Regions.
     */
    @JvmName("rylstigmpdktppmc")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("cnqqbmxbprqxamhs")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values List of AWS Regions.
     */
    @JvmName("owthqiyqjftbdlvb")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value List of S3 bucket ARNs.
     */
    @JvmName("owpannqktnxjwiis")
    public suspend fun buckets(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.buckets = mapped
    }

    /**
     * @param values List of S3 bucket ARNs.
     */
    @JvmName("ewdicxjnfsthbcmh")
    public suspend fun buckets(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.buckets = mapped
    }

    /**
     * @param value List of AWS Regions.
     */
    @JvmName("rtmyixdciktnstrh")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values List of AWS Regions.
     */
    @JvmName("dnufjnipchnoacfr")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    internal fun build(): StorageLensConfigurationStorageLensConfigurationExcludeArgs =
        StorageLensConfigurationStorageLensConfigurationExcludeArgs(
            buckets = buckets,
            regions = regions,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/inputs/StorageLensConfigurationStorageLensConfigurationExcludeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.inputs

import com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property buckets List of S3 bucket ARNs.
 * @property regions List of AWS Regions.
 */
public data class StorageLensConfigurationStorageLensConfigurationExcludeArgs(
    public val buckets: Output<List<String>>? = null,
    public val regions: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs> {
    override fun toJava(): com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs =
        com.pulumi.aws.s3control.inputs.StorageLensConfigurationStorageLensConfigurationExcludeArgs.builder()
            .buckets(buckets?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [StorageLensConfigurationStorageLensConfigurationExcludeArgs].
 */
@PulumiTagMarker
public class StorageLensConfigurationStorageLensConfigurationExcludeArgsBuilder internal constructor() {
    private var buckets: Output<List<String>>? = null

    private var regions: Output<List<String>>? = null

    /**
     * @param value List of S3 bucket ARNs.
     */
    @JvmName("uqnpwmcnvxbnldnr")
    public suspend fun buckets(`value`: Output<List<String>>) {
        this.buckets = value
    }

    @JvmName("vmkuwgiitvsdojub")
    public suspend fun buckets(vararg values: Output<String>) {
        this.buckets = Output.all(values.asList())
    }

    /**
     * @param values List of S3 bucket ARNs.
     */
    @JvmName("sumovfehamewrlxr")
    public suspend fun buckets(values: List<Output<String>>) {
        this.buckets = Output.all(values)
    }

    /**
     * @param value List of AWS Regions.
     */
    @JvmName("fwthenwkwokypgma")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("axavyncqaelwhqfn")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values List of AWS Regions.
     */
    @JvmName("wuteonlgkbcpfbne")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value List of S3 bucket ARNs.
     */
    @JvmName("yfpgqtqgljysjfpo")
    public suspend fun buckets(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.buckets = mapped
    }

    /**
     * @param values List of S3 bucket ARNs.
     */
    @JvmName("rlknlfvneacgcpwm")
    public suspend fun buckets(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.buckets = mapped
    }

    /**
     * @param value List of AWS Regions.
     */
    @JvmName("njrdhxbvbocsdaeq")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values List of AWS Regions.
     */
    @JvmName("xncbordvankormle")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    internal fun build(): StorageLensConfigurationStorageLensConfigurationExcludeArgs =
        StorageLensConfigurationStorageLensConfigurationExcludeArgs(
            buckets = buckets,
            regions = regions,
        )
}
